summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2015-03-05 09:27:29 +0000
committerCaolán McNamara <caolanm@redhat.com>2015-03-05 10:57:33 +0000
commit07d62eb38e591c89e71043f842c92186e33ae14a (patch)
treef64401bc89c13f12737c3baedc67be53a4e7f804
parent967f609cb7bcfd42ccae3d6c8ea75ef9e40910be (diff)
V801: Decreased performance
Change-Id: I5e7b5327b542f610efb0960b8bcfad10e04025b5
-rw-r--r--dbaccess/source/ui/dlg/adminpages.hxx4
-rw-r--r--dbaccess/source/ui/inc/JoinTableView.hxx2
-rw-r--r--dbaccess/source/ui/querydesign/JoinTableView.cxx2
-rw-r--r--dbaccess/source/ui/uno/copytablewizard.cxx4
-rw-r--r--sd/source/ui/dlg/PaneDockingWindow.cxx6
-rw-r--r--sd/source/ui/inc/PaneDockingWindow.hxx2
-rw-r--r--sd/source/ui/slidesorter/controller/SlsDragAndDropContext.cxx4
-rw-r--r--sd/source/ui/slidesorter/controller/SlsDragAndDropContext.hxx2
-rw-r--r--sd/source/ui/slidesorter/controller/SlsScrollBarManager.cxx14
-rw-r--r--sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx12
-rw-r--r--sd/source/ui/slidesorter/controller/SlsVisibleAreaManager.cxx28
-rw-r--r--sd/source/ui/slidesorter/inc/controller/SlsScrollBarManager.hxx2
-rw-r--r--sd/source/ui/slidesorter/inc/controller/SlsSelectionFunction.hxx4
-rw-r--r--sd/source/ui/slidesorter/inc/view/SlsInsertionIndicatorOverlay.hxx6
-rw-r--r--sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx6
-rw-r--r--sd/source/ui/slidesorter/view/SlideSorterView.cxx4
-rw-r--r--sd/source/ui/slidesorter/view/SlsInsertAnimator.cxx28
-rw-r--r--sd/source/ui/slidesorter/view/SlsInsertionIndicatorOverlay.cxx24
-rw-r--r--sd/source/ui/slidesorter/view/SlsLayouter.cxx12
-rw-r--r--slideshow/source/engine/transitions/slidetransitionfactory.cxx4
-rw-r--r--sw/inc/IDocumentMarkAccess.hxx2
-rw-r--r--sw/inc/SwXMLSectionList.hxx2
-rw-r--r--sw/inc/pagepreviewlayout.hxx8
-rw-r--r--sw/inc/unodraw.hxx10
-rw-r--r--sw/source/core/doc/SwStyleNameMapper.cxx2
-rw-r--r--sw/source/core/doc/docbm.cxx2
-rw-r--r--sw/source/core/inc/MarkManager.hxx2
-rw-r--r--sw/source/core/inc/SwXMLBlockExport.hxx4
-rw-r--r--sw/source/core/inc/SwXMLBlockImport.hxx4
-rw-r--r--sw/source/core/inc/UndoTable.hxx2
-rw-r--r--sw/source/core/inc/pagefrm.hxx2
-rw-r--r--sw/source/core/layout/paintfrm.cxx10
-rw-r--r--sw/source/core/swg/SwXMLBlockExport.cxx8
-rw-r--r--sw/source/core/swg/SwXMLBlockImport.cxx8
-rw-r--r--sw/source/core/swg/SwXMLSectionList.cxx4
-rw-r--r--sw/source/core/unocore/unodraw.cxx30
-rw-r--r--sw/source/core/view/pagepreviewlayout.cxx40
-rw-r--r--sw/source/filter/html/htmlforw.cxx2
-rw-r--r--sw/source/filter/html/htmltab.cxx12
-rw-r--r--sw/source/filter/xml/xmlexp.cxx4
-rw-r--r--sw/source/filter/xml/xmlexp.hxx2
-rw-r--r--sw/source/filter/xml/xmlimp.cxx4
-rw-r--r--sw/source/filter/xml/xmlimp.hxx2
-rw-r--r--writerfilter/source/dmapper/DomainMapper.cxx26
-rw-r--r--writerfilter/source/dmapper/DomainMapper.hxx4
-rw-r--r--writerfilter/source/dmapper/DomainMapperTableHandler.cxx12
-rw-r--r--writerfilter/source/dmapper/PropertyMap.cxx12
-rw-r--r--writerfilter/source/dmapper/PropertyMap.hxx2
-rw-r--r--writerfilter/source/dmapper/PropertyMapHelper.cxx2
-rw-r--r--writerfilter/source/dmapper/PropertyMapHelper.hxx2
-rw-r--r--writerfilter/source/ooxml/OOXMLPropertySetImpl.cxx4
-rw-r--r--writerfilter/source/ooxml/OOXMLPropertySetImpl.hxx4
52 files changed, 201 insertions, 203 deletions
diff --git a/dbaccess/source/ui/dlg/adminpages.hxx b/dbaccess/source/ui/dlg/adminpages.hxx
index d822a6a64031..77f4278104a3 100644
--- a/dbaccess/source/ui/dlg/adminpages.hxx
+++ b/dbaccess/source/ui/dlg/adminpages.hxx
@@ -123,9 +123,9 @@ namespace dbaui
@param _rxORB
The service factory.
*/
- void SetServiceFactory(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > _rxORB)
+ void SetServiceFactory(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rxORB)
{
- m_xORB = _rxORB;
+ m_xORB = rxORB;
}
/** opens a dialog filled with all data sources available for this type and
diff --git a/dbaccess/source/ui/inc/JoinTableView.hxx b/dbaccess/source/ui/inc/JoinTableView.hxx
index c6a6d9e67bff..3e77f4df0f1f 100644
--- a/dbaccess/source/ui/inc/JoinTableView.hxx
+++ b/dbaccess/source/ui/inc/JoinTableView.hxx
@@ -131,7 +131,7 @@ namespace dbaui
void BeginChildMove( OTableWindow* pTabWin, const Point& rMousePos );
void BeginChildSizing( OTableWindow* pTabWin, const Pointer& rPointer );
- void NotifyTitleClicked( OTableWindow* pTabWin, const Point rMousePos );
+ void NotifyTitleClicked( OTableWindow* pTabWin, const Point& rMousePos );
virtual void AddTabWin(const OUString& _rComposedName, const OUString& rWinName, bool bNewTable = false);
virtual void RemoveTabWin( OTableWindow* pTabWin );
diff --git a/dbaccess/source/ui/querydesign/JoinTableView.cxx b/dbaccess/source/ui/querydesign/JoinTableView.cxx
index 1b2bc5110cd2..6f3c5950ed2d 100644
--- a/dbaccess/source/ui/querydesign/JoinTableView.cxx
+++ b/dbaccess/source/ui/querydesign/JoinTableView.cxx
@@ -614,7 +614,7 @@ void OJoinTableView::BeginChildMove( OTableWindow* pTabWin, const Point& rMouseP
StartTracking();
}
-void OJoinTableView::NotifyTitleClicked( OTableWindow* pTabWin, const Point rMousePos )
+void OJoinTableView::NotifyTitleClicked( OTableWindow* pTabWin, const Point& rMousePos )
{
DeselectConn(GetSelectedConn());
BeginChildMove(pTabWin, rMousePos);
diff --git a/dbaccess/source/ui/uno/copytablewizard.cxx b/dbaccess/source/ui/uno/copytablewizard.cxx
index e7ad4f93f21f..5a676d190922 100644
--- a/dbaccess/source/ui/uno/copytablewizard.cxx
+++ b/dbaccess/source/ui/uno/copytablewizard.cxx
@@ -671,10 +671,10 @@ Reference< XPropertySet > CopyTableWizard::impl_ensureDataAccessDescriptor_throw
namespace
{
bool lcl_hasNonEmptyStringValue_throw( const Reference< XPropertySet >& _rxDescriptor,
- const Reference< XPropertySetInfo > _rxPSI, const OUString& _rPropertyName )
+ const Reference< XPropertySetInfo >& rxPSI, const OUString& _rPropertyName )
{
OUString sValue;
- if ( _rxPSI->hasPropertyByName( _rPropertyName ) )
+ if ( rxPSI->hasPropertyByName( _rPropertyName ) )
{
OSL_VERIFY( _rxDescriptor->getPropertyValue( _rPropertyName ) >>= sValue );
}
diff --git a/sd/source/ui/dlg/PaneDockingWindow.cxx b/sd/source/ui/dlg/PaneDockingWindow.cxx
index 5363051f0b3e..9461c9326546 100644
--- a/sd/source/ui/dlg/PaneDockingWindow.cxx
+++ b/sd/source/ui/dlg/PaneDockingWindow.cxx
@@ -95,7 +95,7 @@ void PaneDockingWindow::MouseButtonDown (const MouseEvent& rEvent)
SfxDockingWindow::MouseButtonDown(rEvent);
}
-void PaneDockingWindow::SetValidSizeRange (const Range aValidSizeRange)
+void PaneDockingWindow::SetValidSizeRange (const Range& rValidSizeRange)
{
SplitWindow* pSplitWindow = dynamic_cast<SplitWindow*>(GetParent());
if (pSplitWindow != NULL)
@@ -111,8 +111,8 @@ void PaneDockingWindow::SetValidSizeRange (const Range aValidSizeRange)
pSplitWindow->SetItemSizeRange(
nSetId,
Range(
- aValidSizeRange.Min() + nCompensation,
- aValidSizeRange.Max() + nCompensation));
+ rValidSizeRange.Min() + nCompensation,
+ rValidSizeRange.Max() + nCompensation));
}
}
diff --git a/sd/source/ui/inc/PaneDockingWindow.hxx b/sd/source/ui/inc/PaneDockingWindow.hxx
index 54d6bf43a2b3..fd908f7f033a 100644
--- a/sd/source/ui/inc/PaneDockingWindow.hxx
+++ b/sd/source/ui/inc/PaneDockingWindow.hxx
@@ -56,7 +56,7 @@ public:
virtual void MouseButtonDown (const MouseEvent& rEvent) SAL_OVERRIDE;
/** When docked the given range is passed to the parent SplitWindow.
*/
- void SetValidSizeRange (const Range aValidSizeRange);
+ void SetValidSizeRange (const Range& rValidSizeRange);
enum Orientation { HorizontalOrientation, VerticalOrientation, UnknownOrientation };
/** When the PaneDockingWindow is docked and managed by a split window
diff --git a/sd/source/ui/slidesorter/controller/SlsDragAndDropContext.cxx b/sd/source/ui/slidesorter/controller/SlsDragAndDropContext.cxx
index 43eb665d2b04..3338bfeac24e 100644
--- a/sd/source/ui/slidesorter/controller/SlsDragAndDropContext.cxx
+++ b/sd/source/ui/slidesorter/controller/SlsDragAndDropContext.cxx
@@ -111,7 +111,7 @@ void DragAndDropContext::UpdatePosition (
void DragAndDropContext::SetTargetSlideSorter (
SlideSorter* pSlideSorter,
- const Point aMousePosition,
+ const Point& rMousePosition,
const InsertionIndicatorHandler::Mode eMode,
const bool bIsOverSourceView)
{
@@ -129,7 +129,7 @@ void DragAndDropContext::SetTargetSlideSorter (
mpTargetSlideSorter->GetController().GetInsertionIndicatorHandler()->Start(
bIsOverSourceView);
mpTargetSlideSorter->GetController().GetInsertionIndicatorHandler()->UpdatePosition(
- aMousePosition,
+ rMousePosition,
eMode);
}
diff --git a/sd/source/ui/slidesorter/controller/SlsDragAndDropContext.hxx b/sd/source/ui/slidesorter/controller/SlsDragAndDropContext.hxx
index 6887e7b53e4e..9af4797e3478 100644
--- a/sd/source/ui/slidesorter/controller/SlsDragAndDropContext.hxx
+++ b/sd/source/ui/slidesorter/controller/SlsDragAndDropContext.hxx
@@ -62,7 +62,7 @@ public:
void SetTargetSlideSorter (
SlideSorter* pSlideSorter = NULL,
- const Point aMousePosition = Point(0,0),
+ const Point& rMousePosition = Point(0,0),
const InsertionIndicatorHandler::Mode eMode = InsertionIndicatorHandler::UnknownMode,
const bool bIsOverSourceView = false);
diff --git a/sd/source/ui/slidesorter/controller/SlsScrollBarManager.cxx b/sd/source/ui/slidesorter/controller/SlsScrollBarManager.cxx
index 34305272a043..d82a0e004bd7 100644
--- a/sd/source/ui/slidesorter/controller/SlsScrollBarManager.cxx
+++ b/sd/source/ui/slidesorter/controller/SlsScrollBarManager.cxx
@@ -407,12 +407,12 @@ bool ScrollBarManager::TestScrollBarVisibilities (
return false;
}
-void ScrollBarManager::SetTopLeft (const Point aNewTopLeft)
+void ScrollBarManager::SetTopLeft(const Point& rNewTopLeft)
{
if (( ! mpVerticalScrollBar
- || mpVerticalScrollBar->GetThumbPos() == aNewTopLeft.Y())
+ || mpVerticalScrollBar->GetThumbPos() == rNewTopLeft.Y())
&& ( ! mpHorizontalScrollBar
- || mpHorizontalScrollBar->GetThumbPos() == aNewTopLeft.X()))
+ || mpHorizontalScrollBar->GetThumbPos() == rNewTopLeft.X()))
return;
// Flush pending repaints before scrolling to avoid temporary artifacts.
@@ -420,13 +420,13 @@ void ScrollBarManager::SetTopLeft (const Point aNewTopLeft)
if (mpVerticalScrollBar)
{
- mpVerticalScrollBar->SetThumbPos(aNewTopLeft.Y());
- mnVerticalPosition = aNewTopLeft.Y() / double(mpVerticalScrollBar->GetRange().Len());
+ mpVerticalScrollBar->SetThumbPos(rNewTopLeft.Y());
+ mnVerticalPosition = rNewTopLeft.Y() / double(mpVerticalScrollBar->GetRange().Len());
}
if (mpHorizontalScrollBar)
{
- mpHorizontalScrollBar->SetThumbPos(aNewTopLeft.X());
- mnHorizontalPosition = aNewTopLeft.X() / double(mpHorizontalScrollBar->GetRange().Len());
+ mpHorizontalScrollBar->SetThumbPos(rNewTopLeft.X());
+ mnHorizontalPosition = rNewTopLeft.X() / double(mpHorizontalScrollBar->GetRange().Len());
}
mrSlideSorter.GetContentWindow()->SetVisibleXY(mnHorizontalPosition, mnVerticalPosition);
diff --git a/sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx b/sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx
index 071f2819af94..64ee5effc7e8 100644
--- a/sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx
+++ b/sd/source/ui/slidesorter/controller/SlsSelectionFunction.cxx
@@ -701,7 +701,7 @@ void SelectionFunction::SwitchToNormalMode (void)
new NormalModeHandler(mrSlideSorter, *this)));
}
-void SelectionFunction::SwitchToDragAndDropMode (const Point aMousePosition)
+void SelectionFunction::SwitchToDragAndDropMode (const Point& rMousePosition)
{
if (mpModeHandler->GetMode() != DragAndDropMode)
{
@@ -712,23 +712,23 @@ void SelectionFunction::SwitchToDragAndDropMode (const Point aMousePosition)
// Delayed initialization, only after mpModeHanler is set, otherwise DND initialization
// could already trigger DND events, which would recursively trigger this code again,
// and without mpModeHandler set it would again try to set a new handler.
- handler->Initialize(aMousePosition, mpWindow);
+ handler->Initialize(rMousePosition, mpWindow);
#else
SwitchMode(::boost::shared_ptr<ModeHandler>(
- new DragAndDropModeHandler(mrSlideSorter, *this, aMousePosition, mpWindow)));
+ new DragAndDropModeHandler(mrSlideSorter, *this, rMousePosition, mpWindow)));
#endif
}
}
void SelectionFunction::SwitchToMultiSelectionMode (
- const Point aMousePosition,
+ const Point& rMousePosition,
const sal_uInt32 nEventCode)
{
if (mpModeHandler->GetMode() != MultiSelectionMode)
#ifndef MACOSX
{
::boost::shared_ptr<MultiSelectionModeHandler> handler(
- new MultiSelectionModeHandler(mrSlideSorter, *this, aMousePosition));
+ new MultiSelectionModeHandler(mrSlideSorter, *this, rMousePosition));
SwitchMode(handler);
// Delayed initialization, only after mpModeHanler is set, the handle ctor
// is non-trivial, so it could possibly recurse just like the DND handler above.
@@ -736,7 +736,7 @@ void SelectionFunction::SwitchToMultiSelectionMode (
}
#else
SwitchMode(::boost::shared_ptr<ModeHandler>(
- new MultiSelectionModeHandler(mrSlideSorter, *this, aMousePosition, nEventCode)));
+ new MultiSelectionModeHandler(mrSlideSorter, *this, rMousePosition, nEventCode)));
#endif
}
diff --git a/sd/source/ui/slidesorter/controller/SlsVisibleAreaManager.cxx b/sd/source/ui/slidesorter/controller/SlsVisibleAreaManager.cxx
index a008fa1b91ab..8ccb1106c5e6 100644
--- a/sd/source/ui/slidesorter/controller/SlsVisibleAreaManager.cxx
+++ b/sd/source/ui/slidesorter/controller/SlsVisibleAreaManager.cxx
@@ -36,8 +36,8 @@ namespace {
public:
VisibleAreaScroller (
SlideSorter& rSlideSorter,
- const Point aStart,
- const Point aEnd);
+ const Point& rStart,
+ const Point& rEnd);
void operator() (const double nValue);
private:
SlideSorter& mrSlideSorter;
@@ -221,11 +221,11 @@ const static sal_Int32 gnMaxScrollDistance = 300;
VisibleAreaScroller::VisibleAreaScroller (
SlideSorter& rSlideSorter,
- const Point aStart,
- const Point aEnd)
+ const Point& rStart,
+ const Point& rEnd)
: mrSlideSorter(rSlideSorter),
- maStart(aStart),
- maEnd(aEnd),
+ maStart(rStart),
+ maEnd(rEnd),
maAccelerationFunction(
controller::AnimationParametricFunction(
controller::AnimationBezierFunction (0.1,0.6)))
@@ -233,19 +233,19 @@ VisibleAreaScroller::VisibleAreaScroller (
// When the distance to scroll is larger than a threshold then first
// jump to within this distance of the final value and start the
// animation from there.
- if (std::abs(aStart.X()-aEnd.X()) > gnMaxScrollDistance)
+ if (std::abs(rStart.X()-rEnd.X()) > gnMaxScrollDistance)
{
- if (aStart.X() < aEnd.X())
- maStart.X() = aEnd.X()-gnMaxScrollDistance;
+ if (rStart.X() < rEnd.X())
+ maStart.X() = rEnd.X()-gnMaxScrollDistance;
else
- maStart.X() = aEnd.X()+gnMaxScrollDistance;
+ maStart.X() = rEnd.X()+gnMaxScrollDistance;
}
- if (std::abs(aStart.Y()-aEnd.Y()) > gnMaxScrollDistance)
+ if (std::abs(rStart.Y()-rEnd.Y()) > gnMaxScrollDistance)
{
- if (aStart.Y() < aEnd.Y())
- maStart.Y() = aEnd.Y()-gnMaxScrollDistance;
+ if (rStart.Y() < rEnd.Y())
+ maStart.Y() = rEnd.Y()-gnMaxScrollDistance;
else
- maStart.Y() = aEnd.Y()+gnMaxScrollDistance;
+ maStart.Y() = rEnd.Y()+gnMaxScrollDistance;
}
}
diff --git a/sd/source/ui/slidesorter/inc/controller/SlsScrollBarManager.hxx b/sd/source/ui/slidesorter/inc/controller/SlsScrollBarManager.hxx
index 8a7fe7c93d57..5e70abfdfeba 100644
--- a/sd/source/ui/slidesorter/inc/controller/SlsScrollBarManager.hxx
+++ b/sd/source/ui/slidesorter/inc/controller/SlsScrollBarManager.hxx
@@ -125,7 +125,7 @@ public:
/** Update the vertical and horizontal scroll bars so that the visible
area has the given top and left values.
*/
- void SetTopLeft (const Point aNewTopLeft);
+ void SetTopLeft (const Point& rNewTopLeft);
/** Return the width of the vertical scroll bar, which--when
shown--should be fixed in contrast to its height.
diff --git a/sd/source/ui/slidesorter/inc/controller/SlsSelectionFunction.hxx b/sd/source/ui/slidesorter/inc/controller/SlsSelectionFunction.hxx
index 8128b6b14301..6142fdf7f587 100644
--- a/sd/source/ui/slidesorter/inc/controller/SlsSelectionFunction.hxx
+++ b/sd/source/ui/slidesorter/inc/controller/SlsSelectionFunction.hxx
@@ -96,8 +96,8 @@ public:
ButtonMode
};
void SwitchToNormalMode (void);
- void SwitchToDragAndDropMode(const Point aMousePosition);
- void SwitchToMultiSelectionMode (const Point aMousePosition, const sal_uInt32 nEventCode);
+ void SwitchToDragAndDropMode(const Point& rMousePosition);
+ void SwitchToMultiSelectionMode (const Point& rMousePosition, const sal_uInt32 nEventCode);
void ResetShiftKeySelectionAnchor (void);
/** Special case handling for when the context menu is hidden. This
diff --git a/sd/source/ui/slidesorter/inc/view/SlsInsertionIndicatorOverlay.hxx b/sd/source/ui/slidesorter/inc/view/SlsInsertionIndicatorOverlay.hxx
index 4479aaa2fd3c..6424c027232c 100644
--- a/sd/source/ui/slidesorter/inc/view/SlsInsertionIndicatorOverlay.hxx
+++ b/sd/source/ui/slidesorter/inc/view/SlsInsertionIndicatorOverlay.hxx
@@ -92,14 +92,14 @@ private:
void SetPositionAndSize (const Rectangle& rBoundingBox);
Point PaintRepresentatives (
OutputDevice& rContent,
- const Size aPreviewSize,
+ const Size& rPreviewSize,
const sal_Int32 nOffset,
const ::std::vector<controller::TransferableData::Representative>& rPages) const;
void PaintPageCount (
OutputDevice& rDevice,
const sal_Int32 nSelectionCount,
- const Size aPreviewSize,
- const Point aFirstPageOffset) const;
+ const Size& rPreviewSize,
+ const Point& rFirstPageOffset) const;
/** Setup the insertion indicator by creating the icon. It consists of
scaled down previews of some of the selected pages.
*/
diff --git a/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx b/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx
index a04d5fba8733..4402129fc36f 100644
--- a/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx
+++ b/sd/source/ui/slidesorter/inc/view/SlsLayouter.hxx
@@ -214,9 +214,9 @@ public:
const bool bIsAtRunEnd,
const bool bIsExtraSpaceNeeded);
void SetGeometricalPosition(
- const Point aLocation,
- const Point aLeadingOffset,
- const Point aTrailingOffset);
+ const Point& rLocation,
+ const Point& rLeadingOffset,
+ const Point& rTrailingOffset);
sal_Int32 GetRow (void) const { return mnRow; }
sal_Int32 GetColumn (void) const { return mnColumn; }
diff --git a/sd/source/ui/slidesorter/view/SlideSorterView.cxx b/sd/source/ui/slidesorter/view/SlideSorterView.cxx
index 4d34b14cae8e..7b60a294f2a6 100644
--- a/sd/source/ui/slidesorter/view/SlideSorterView.cxx
+++ b/sd/source/ui/slidesorter/view/SlideSorterView.cxx
@@ -108,7 +108,7 @@ class BackgroundPainter
public ::boost::noncopyable
{
public:
- BackgroundPainter (const Color aBackgroundColor) : maBackgroundColor(aBackgroundColor) {}
+ BackgroundPainter (const Color& rBackgroundColor) : maBackgroundColor(rBackgroundColor) {}
virtual ~BackgroundPainter (void) {}
virtual void Paint (OutputDevice& rDevice, const Rectangle& rRepaintArea) SAL_OVERRIDE
@@ -120,7 +120,7 @@ public:
virtual void SetLayerInvalidator (const SharedILayerInvalidator&) SAL_OVERRIDE {}
- void SetColor (const Color aColor) { maBackgroundColor = aColor; }
+ void SetColor (const Color& rColor) { maBackgroundColor = rColor; }
private:
Color maBackgroundColor;
diff --git a/sd/source/ui/slidesorter/view/SlsInsertAnimator.cxx b/sd/source/ui/slidesorter/view/SlsInsertAnimator.cxx
index a873e4e1399e..8fb9eba6deab 100644
--- a/sd/source/ui/slidesorter/view/SlsInsertAnimator.cxx
+++ b/sd/source/ui/slidesorter/view/SlsInsertAnimator.cxx
@@ -38,8 +38,8 @@ class PageObjectRun;
class AnimatorAccess
{
public:
- virtual void AddRun (const ::boost::shared_ptr<PageObjectRun> pRun) = 0;
- virtual void RemoveRun (const ::boost::shared_ptr<PageObjectRun> pRun) = 0;
+ virtual void AddRun (const ::boost::shared_ptr<PageObjectRun>& rRun) = 0;
+ virtual void RemoveRun (const ::boost::shared_ptr<PageObjectRun>& rRun) = 0;
virtual model::SlideSorterModel& GetModel (void) const = 0;
virtual view::SlideSorterView& GetView (void) const = 0;
virtual ::boost::shared_ptr<controller::Animator> GetAnimator (void) = 0;
@@ -122,8 +122,8 @@ public:
const InsertPosition& rInsertPosition,
const controller::Animator::AnimationMode eAnimationMode);
- virtual void AddRun (const ::boost::shared_ptr<PageObjectRun> pRun) SAL_OVERRIDE;
- virtual void RemoveRun (const ::boost::shared_ptr<PageObjectRun> pRun) SAL_OVERRIDE;
+ virtual void AddRun (const ::boost::shared_ptr<PageObjectRun>& rRun) SAL_OVERRIDE;
+ virtual void RemoveRun (const ::boost::shared_ptr<PageObjectRun>& rRun) SAL_OVERRIDE;
virtual model::SlideSorterModel& GetModel (void) const SAL_OVERRIDE { return mrModel; }
virtual view::SlideSorterView& GetView (void) const SAL_OVERRIDE { return mrView; }
@@ -264,36 +264,36 @@ InsertAnimator::Implementation::RunContainer::const_iterator
nRunIndex));
}
-void InsertAnimator::Implementation::AddRun (const ::boost::shared_ptr<PageObjectRun> pRun)
+void InsertAnimator::Implementation::AddRun (const ::boost::shared_ptr<PageObjectRun>& rRun)
{
- if (pRun)
+ if (rRun)
{
- maRuns.insert(pRun);
+ maRuns.insert(rRun);
}
else
{
- OSL_ASSERT(pRun);
+ OSL_ASSERT(rRun);
}
}
-void InsertAnimator::Implementation::RemoveRun (const ::boost::shared_ptr<PageObjectRun> pRun)
+void InsertAnimator::Implementation::RemoveRun (const ::boost::shared_ptr<PageObjectRun>& rRun)
{
- if (pRun)
+ if (rRun)
{
// Do not remove runs that show the space for the insertion indicator.
- if (pRun->mnLocalInsertIndex == -1)
+ if (rRun->mnLocalInsertIndex == -1)
{
- InsertAnimator::Implementation::RunContainer::const_iterator iRun (FindRun(pRun->mnRunIndex));
+ InsertAnimator::Implementation::RunContainer::const_iterator iRun (FindRun(rRun->mnRunIndex));
if (iRun != maRuns.end())
{
- OSL_ASSERT(*iRun == pRun);
+ OSL_ASSERT(*iRun == rRun);
maRuns.erase(iRun);
}
}
}
else
{
- OSL_ASSERT(pRun);
+ OSL_ASSERT(rRun);
}
}
diff --git a/sd/source/ui/slidesorter/view/SlsInsertionIndicatorOverlay.cxx b/sd/source/ui/slidesorter/view/SlsInsertionIndicatorOverlay.cxx
index a916b40580c0..6862a69dccd1 100644
--- a/sd/source/ui/slidesorter/view/SlsInsertionIndicatorOverlay.cxx
+++ b/sd/source/ui/slidesorter/view/SlsInsertionIndicatorOverlay.cxx
@@ -152,7 +152,7 @@ void InsertionIndicatorOverlay::Create (
Point InsertionIndicatorOverlay::PaintRepresentatives (
OutputDevice& rContent,
- const Size aPreviewSize,
+ const Size& rPreviewSize,
const sal_Int32 nOffset,
const ::std::vector<controller::TransferableData::Representative>& rRepresentatives) const
{
@@ -187,7 +187,7 @@ Point InsertionIndicatorOverlay::PaintRepresentatives (
// Paint the preview.
Bitmap aPreview (rRepresentatives[nIndex].maBitmap);
- aPreview.Scale(aPreviewSize, BMP_SCALE_BESTQUALITY);
+ aPreview.Scale(rPreviewSize, BMP_SCALE_BESTQUALITY);
rContent.DrawBitmapEx(aPageOffset, aPreview);
// When the page is marked as excluded from the slide show then
@@ -195,14 +195,14 @@ Point InsertionIndicatorOverlay::PaintRepresentatives (
if (rRepresentatives[nIndex].mbIsExcluded)
{
const vcl::Region aSavedClipRegion (rContent.GetClipRegion());
- rContent.IntersectClipRegion(Rectangle(aPageOffset, aPreviewSize));
+ rContent.IntersectClipRegion(Rectangle(aPageOffset, rPreviewSize));
// Paint bitmap tiled over the preview to mark it as excluded.
const sal_Int32 nIconWidth (aExclusionOverlay.GetSizePixel().Width());
const sal_Int32 nIconHeight (aExclusionOverlay.GetSizePixel().Height());
if (nIconWidth>0 && nIconHeight>0)
{
- for (sal_Int32 nX=0; nX<aPreviewSize.Width(); nX+=nIconWidth)
- for (sal_Int32 nY=0; nY<aPreviewSize.Height(); nY+=nIconHeight)
+ for (sal_Int32 nX=0; nX<rPreviewSize.Width(); nX+=nIconWidth)
+ for (sal_Int32 nY=0; nY<rPreviewSize.Height(); nY+=nIconHeight)
rContent.DrawBitmapEx(Point(nX,nY)+aPageOffset, aExclusionOverlay);
}
rContent.SetClipRegion(aSavedClipRegion);
@@ -212,8 +212,8 @@ Point InsertionIndicatorOverlay::PaintRepresentatives (
Rectangle aBox (
aPageOffset.X(),
aPageOffset.Y(),
- aPageOffset.X()+aPreviewSize.Width()-1,
- aPageOffset.Y()+aPreviewSize.Height()-1);
+ aPageOffset.X()+rPreviewSize.Width()-1,
+ aPageOffset.Y()+rPreviewSize.Height()-1);
rContent.SetFillColor(COL_BLACK);
rContent.SetLineColor();
rContent.DrawTransparent(
@@ -239,8 +239,8 @@ Point InsertionIndicatorOverlay::PaintRepresentatives (
void InsertionIndicatorOverlay::PaintPageCount (
OutputDevice& rDevice,
const sal_Int32 nSelectionCount,
- const Size aPreviewSize,
- const Point aFirstPageOffset) const
+ const Size& rPreviewSize,
+ const Point& rFirstPageOffset) const
{
// Paint the number of slides.
::boost::shared_ptr<view::Theme> pTheme (mrSlideSorter.GetTheme());
@@ -257,11 +257,11 @@ void InsertionIndicatorOverlay::PaintPageCount (
Point aTextOffset (aTextBox.TopLeft());
Size aTextSize (aTextBox.GetSize());
// Place text inside the first page preview.
- Point aTextLocation(aFirstPageOffset);
+ Point aTextLocation(rFirstPageOffset);
// Center the text.
aTextLocation += Point(
- (aPreviewSize.Width()-aTextBox.GetWidth())/2,
- (aPreviewSize.Height()-aTextBox.GetHeight())/2);
+ (rPreviewSize.Width()-aTextBox.GetWidth())/2,
+ (rPreviewSize.Height()-aTextBox.GetHeight())/2);
aTextBox = Rectangle(aTextLocation, aTextSize);
// Paint background, border and text.
diff --git a/sd/source/ui/slidesorter/view/SlsLayouter.cxx b/sd/source/ui/slidesorter/view/SlsLayouter.cxx
index bcffcab40632..155652f3d487 100644
--- a/sd/source/ui/slidesorter/view/SlsLayouter.cxx
+++ b/sd/source/ui/slidesorter/view/SlsLayouter.cxx
@@ -1249,13 +1249,13 @@ void InsertPosition::SetLogicalPosition (
}
void InsertPosition::SetGeometricalPosition(
- const Point aLocation,
- const Point aLeadingOffset,
- const Point aTrailingOffset)
+ const Point& rLocation,
+ const Point& rLeadingOffset,
+ const Point& rTrailingOffset)
{
- maLocation = aLocation;
- maLeadingOffset = aLeadingOffset;
- maTrailingOffset = aTrailingOffset;
+ maLocation = rLocation;
+ maLeadingOffset = rLeadingOffset;
+ maTrailingOffset = rTrailingOffset;
}
} } } // end of namespace ::sd::slidesorter::namespace
diff --git a/slideshow/source/engine/transitions/slidetransitionfactory.cxx b/slideshow/source/engine/transitions/slidetransitionfactory.cxx
index a390f3ac5a1b..754e4f060a50 100644
--- a/slideshow/source/engine/transitions/slidetransitionfactory.cxx
+++ b/slideshow/source/engine/transitions/slidetransitionfactory.cxx
@@ -97,10 +97,10 @@ class PluginSlideChange: public SlideChangeBase
uno::Reference<presentation::XTransition> mxTransition;
UnoViewSharedPtr mpView;
- TransitionViewPair( uno::Reference<presentation::XTransition> xTransition, const UnoViewSharedPtr pView )
+ TransitionViewPair( uno::Reference<presentation::XTransition> xTransition, const UnoViewSharedPtr& rView )
{
mxTransition = xTransition;
- mpView = pView;
+ mpView = rView;
}
~TransitionViewPair()
diff --git a/sw/inc/IDocumentMarkAccess.hxx b/sw/inc/IDocumentMarkAccess.hxx
index 07af6701ce8c..c699addc8be2 100644
--- a/sw/inc/IDocumentMarkAccess.hxx
+++ b/sw/inc/IDocumentMarkAccess.hxx
@@ -180,7 +180,7 @@ class IDocumentMarkAccess
[in] an iterator pointing to the Mark to be deleted.
*/
virtual ::boost::shared_ptr<ILazyDeleter>
- deleteMark(const IDocumentMarkAccess::const_iterator_t ppMark) =0;
+ deleteMark(const IDocumentMarkAccess::const_iterator_t& ppMark) =0;
/** Deletes a mark.
diff --git a/sw/inc/SwXMLSectionList.hxx b/sw/inc/SwXMLSectionList.hxx
index 110ef13a6b72..0a727d57b46d 100644
--- a/sw/inc/SwXMLSectionList.hxx
+++ b/sw/inc/SwXMLSectionList.hxx
@@ -35,7 +35,7 @@ public:
std::vector<OUString*> &rSectionList;
SwXMLSectionList(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > xContext,
+ const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rContext,
std::vector<OUString*> &rNewSectionList );
virtual ~SwXMLSectionList ( )
diff --git a/sw/inc/pagepreviewlayout.hxx b/sw/inc/pagepreviewlayout.hxx
index 8c01106fd179..ba4abc38115c 100644
--- a/sw/inc/pagepreviewlayout.hxx
+++ b/sw/inc/pagepreviewlayout.hxx
@@ -328,7 +328,7 @@ public:
@return boolean, indicating, if prepare of preview paint was successful.
*/
bool Prepare( const sal_uInt16 _nProposedStartPageNum,
- const Point _aProposedStartPos,
+ const Point& rProposedStartPos,
const Size& _rPxWinSize,
sal_uInt16& _onStartPageNum,
Rectangle& _orDocPreviewPaintRect,
@@ -362,7 +362,7 @@ public:
@return boolean, indicating, if paint of preview was performed
*/
- bool Paint( const Rectangle _aOutRect ) const;
+ bool Paint( const Rectangle& rOutRect ) const;
/** repaint pages on page preview
@@ -371,7 +371,7 @@ public:
@author OD
*/
- void Repaint( const Rectangle _aInvalidCoreRect ) const;
+ void Repaint(const Rectangle& rInvalidCoreRect) const;
/** paint to mark new selected page
@@ -466,7 +466,7 @@ public:
@return boolean - indicating, that given preview position lays inside
a shown document preview page, not an empty page.
*/
- bool IsPreviewPosInDocPreviewPage( const Point _aPreviewPos,
+ bool IsPreviewPosInDocPreviewPage( const Point& rPreviewPos,
Point& _orDocPos,
bool& _obPosInEmptyPage,
sal_uInt16& _onPageNum ) const;
diff --git a/sw/inc/unodraw.hxx b/sw/inc/unodraw.hxx
index be30e27be0a3..04b90a68c2f8 100644
--- a/sw/inc/unodraw.hxx
+++ b/sw/inc/unodraw.hxx
@@ -54,8 +54,8 @@ public:
SwFmDrawPage( SdrPage* pPage );
virtual ~SwFmDrawPage() throw ();
- const SdrMarkList& PreGroup(const ::com::sun::star::uno::Reference< ::com::sun::star::drawing::XShapes > & xShapes);
- void PreUnGroup(const ::com::sun::star::uno::Reference< ::com::sun::star::drawing::XShapeGroup > xShapeGroup);
+ const SdrMarkList& PreGroup(const ::com::sun::star::uno::Reference< ::com::sun::star::drawing::XShapes >& rShapes);
+ void PreUnGroup(const ::com::sun::star::uno::Reference< ::com::sun::star::drawing::XShapeGroup >& rShapeGroup);
SdrView* GetDrawView() {return mpView;}
SdrPageView* GetPageView();
@@ -173,8 +173,8 @@ class SwXShape : public SwXShapeBaseClass,
@author OD
*/
::com::sun::star::awt::Point _ConvertPositionToHoriL2R(
- const ::com::sun::star::awt::Point _aObjPos,
- const ::com::sun::star::awt::Size _aObjSize );
+ const css::awt::Point& rObjPos,
+ const css::awt::Size& rObjSize );
/** method to convert the transformation of the drawing object to the layout
direction, the drawing object is in
@@ -193,7 +193,7 @@ class SwXShape : public SwXShapeBaseClass,
has to be given in the layout direction the shape is in and relative to
its position alignment areas.
*/
- void _AdjustPositionProperties( const ::com::sun::star::awt::Point _aPosition );
+ void _AdjustPositionProperties(const css::awt::Point& rPosition);
/** method to convert start or end position of the drawing object to the
Writer specific position, which is the attribute position in layout direction
diff --git a/sw/source/core/doc/SwStyleNameMapper.cxx b/sw/source/core/doc/SwStyleNameMapper.cxx
index 20df27fc3837..dab5cf8a00c7 100644
--- a/sw/source/core/doc/SwStyleNameMapper.cxx
+++ b/sw/source/core/doc/SwStyleNameMapper.cxx
@@ -394,7 +394,7 @@ static void lcl_CheckSuffixAndDelete(OUString & rString)
typedef boost::tuple<sal_uInt16, sal_uInt16, const ::std::vector<OUString>& (*)() > NameArrayIndexTuple_t;
-static sal_uInt16 lcl_AccumulateIndexCount( sal_uInt16 nSum, NameArrayIndexTuple_t const tuple ){
+static sal_uInt16 lcl_AccumulateIndexCount( sal_uInt16 nSum, const NameArrayIndexTuple_t& tuple ){
// Return running sum + (index end) - (index start)
return nSum + boost::get<1>( tuple ) - boost::get<0>( tuple );
}
diff --git a/sw/source/core/doc/docbm.cxx b/sw/source/core/doc/docbm.cxx
index 72fdf6d2e498..b239e8834136 100644
--- a/sw/source/core/doc/docbm.cxx
+++ b/sw/source/core/doc/docbm.cxx
@@ -847,7 +847,7 @@ namespace sw { namespace mark
};
::boost::shared_ptr<IDocumentMarkAccess::ILazyDeleter>
- MarkManager::deleteMark(const const_iterator_t ppMark)
+ MarkManager::deleteMark(const const_iterator_t& ppMark)
{
::boost::shared_ptr<ILazyDeleter> ret;
if (ppMark == m_vAllMarks.end()) return ret;
diff --git a/sw/source/core/inc/MarkManager.hxx b/sw/source/core/inc/MarkManager.hxx
index d5f99f75ad83..dbc7e39f7541 100644
--- a/sw/source/core/inc/MarkManager.hxx
+++ b/sw/source/core/inc/MarkManager.hxx
@@ -59,7 +59,7 @@ namespace sw {
// deleters
virtual ::boost::shared_ptr<ILazyDeleter>
- deleteMark(const const_iterator_t ppMark) SAL_OVERRIDE;
+ deleteMark(const const_iterator_t& ppMark) SAL_OVERRIDE;
virtual void deleteMark(const ::sw::mark::IMark* const pMark) SAL_OVERRIDE;
virtual void clearAllMarks() SAL_OVERRIDE;
diff --git a/sw/source/core/inc/SwXMLBlockExport.hxx b/sw/source/core/inc/SwXMLBlockExport.hxx
index ff62ced64fd8..a0c7ed43bc89 100644
--- a/sw/source/core/inc/SwXMLBlockExport.hxx
+++ b/sw/source/core/inc/SwXMLBlockExport.hxx
@@ -31,7 +31,7 @@ private:
public:
SwXMLBlockListExport(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > xContext,
+ const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rContext,
SwXMLTextBlocks & rBlocks,
const OUString &rFileName,
com::sun::star::uno::Reference< com::sun::star::xml::sax::XDocumentHandler> &rHandler);
@@ -50,7 +50,7 @@ private:
public:
SwXMLTextBlockExport(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > xContext,
+ const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rContext,
SwXMLTextBlocks & rBlocks,
const OUString &rFileName,
com::sun::star::uno::Reference< com::sun::star::xml::sax::XDocumentHandler> &rHandler);
diff --git a/sw/source/core/inc/SwXMLBlockImport.hxx b/sw/source/core/inc/SwXMLBlockImport.hxx
index 9c4e77c388cf..aa6ea1a9110f 100644
--- a/sw/source/core/inc/SwXMLBlockImport.hxx
+++ b/sw/source/core/inc/SwXMLBlockImport.hxx
@@ -44,7 +44,7 @@ protected:
public:
SwXMLBlockListImport(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > xContext,
+ const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rContext,
SwXMLTextBlocks &rBlocks );
SwXMLTextBlocks& getBlockList ( void )
@@ -70,7 +70,7 @@ public:
bool bTextOnly;
OUString &m_rText;
SwXMLTextBlockImport(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > xContext,
+ const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rContext,
SwXMLTextBlocks &rBlocks, OUString &rNewText, bool bNewTextOnly );
SwXMLTextBlocks& getBlockList ( void )
diff --git a/sw/source/core/inc/UndoTable.hxx b/sw/source/core/inc/UndoTable.hxx
index 6aac04f35f23..b4263bcdf4dd 100644
--- a/sw/source/core/inc/UndoTable.hxx
+++ b/sw/source/core/inc/UndoTable.hxx
@@ -171,7 +171,7 @@ class SwUndoTblNdsChg : public SwUndo, private boost::noncopyable
sal_uLong index; ///< Index of this box.
bool hasMoved; ///< Has this box been moved already.
_BoxMove(sal_uLong idx, bool moved=false) : index(idx), hasMoved(moved) {};
- bool operator<(const _BoxMove other) const { return index < other.index; };
+ bool operator<(const _BoxMove& other) const { return index < other.index; };
};
std::unique_ptr< std::set<_BoxMove> > pNewSttNds;
std::unique_ptr< SwUndoSaveSections > pDelSects;
diff --git a/sw/source/core/inc/pagefrm.hxx b/sw/source/core/inc/pagefrm.hxx
index 52b86063942f..d626391bd948 100644
--- a/sw/source/core/inc/pagefrm.hxx
+++ b/sw/source/core/inc/pagefrm.hxx
@@ -304,7 +304,7 @@ public:
);
static void PaintNotesSidebar(const SwRect& _rPageRect, SwViewShell* _pViewShell, sal_uInt16 nPageNum, bool bRight);
- static void PaintNotesSidebarArrows(const Point &aMiddleFirst, const Point &aMiddleSecond, SwViewShell* _pViewShell, const Color aColorUp, const Color aColorDown);
+ static void PaintNotesSidebarArrows(const Point &rMiddleFirst, const Point &rMiddleSecond, SwViewShell* _pViewShell, const Color& rColorUp, const Color& rColorDown);
/**
asks the page on which side a margin should be shown, e.g for notes
returns true for left side, false for right side
diff --git a/sw/source/core/swg/SwXMLBlockExport.cxx b/sw/source/core/swg/SwXMLBlockExport.cxx
index a599d8a2c53d..46ed5f73220e 100644
--- a/sw/source/core/swg/SwXMLBlockExport.cxx
+++ b/sw/source/core/swg/SwXMLBlockExport.cxx
@@ -28,11 +28,11 @@ using namespace ::xmloff::token;
// #110680#
SwXMLBlockListExport::SwXMLBlockListExport(
- const uno::Reference< uno::XComponentContext > xContext,
+ const uno::Reference< uno::XComponentContext >& rContext,
SwXMLTextBlocks & rBlocks,
const OUString &rFileName,
uno::Reference< xml::sax::XDocumentHandler> &rHandler)
-: SvXMLExport( xContext, "", rFileName, util::MeasureUnit::CM, rHandler ),
+: SvXMLExport( rContext, "", rFileName, util::MeasureUnit::CM, rHandler ),
rBlockList(rBlocks)
{
_GetNamespaceMap().Add( GetXMLToken ( XML_NP_BLOCK_LIST ),
@@ -79,11 +79,11 @@ sal_uInt32 SwXMLBlockListExport::exportDoc(enum XMLTokenEnum )
// #110680#
SwXMLTextBlockExport::SwXMLTextBlockExport(
- const uno::Reference< uno::XComponentContext > xContext,
+ const uno::Reference< uno::XComponentContext >& rContext,
SwXMLTextBlocks & rBlocks,
const OUString &rFileName,
uno::Reference< xml::sax::XDocumentHandler> &rHandler)
-: SvXMLExport( xContext, "", rFileName, util::MeasureUnit::CM, rHandler ),
+: SvXMLExport( rContext, "", rFileName, util::MeasureUnit::CM, rHandler ),
rBlockList(rBlocks)
{
_GetNamespaceMap().Add( GetXMLToken ( XML_NP_BLOCK_LIST ),
diff --git a/sw/source/core/swg/SwXMLBlockImport.cxx b/sw/source/core/swg/SwXMLBlockImport.cxx
index 69e93c553926..d0fa4afd0b15 100644
--- a/sw/source/core/swg/SwXMLBlockImport.cxx
+++ b/sw/source/core/swg/SwXMLBlockImport.cxx
@@ -347,9 +347,9 @@ SwXMLTextBlockParContext::~SwXMLTextBlockParContext ( void )
// SwXMLBlockListImport //////////////////////////////
SwXMLBlockListImport::SwXMLBlockListImport(
- const uno::Reference< uno::XComponentContext > xContext,
+ const uno::Reference< uno::XComponentContext >& rContext,
SwXMLTextBlocks &rBlocks )
-: SvXMLImport( xContext, "", SvXMLImportFlags::NONE ),
+: SvXMLImport( rContext, "", SvXMLImportFlags::NONE ),
rBlockList (rBlocks)
{
}
@@ -369,11 +369,11 @@ SvXMLImportContext* SwXMLBlockListImport::CreateFastContext( sal_Int32 Element,
}
SwXMLTextBlockImport::SwXMLTextBlockImport(
- const uno::Reference< uno::XComponentContext > xContext,
+ const uno::Reference< uno::XComponentContext >& rContext,
SwXMLTextBlocks &rBlocks,
OUString & rNewText,
bool bNewTextOnly )
-: SvXMLImport(xContext, "", SvXMLImportFlags::ALL ),
+: SvXMLImport(rContext, "", SvXMLImportFlags::ALL ),
rBlockList ( rBlocks ),
bTextOnly ( bNewTextOnly ),
m_rText ( rNewText )
diff --git a/sw/source/core/swg/SwXMLSectionList.cxx b/sw/source/core/swg/SwXMLSectionList.cxx
index a92e29061c46..4ce19c7e4eae 100644
--- a/sw/source/core/swg/SwXMLSectionList.cxx
+++ b/sw/source/core/swg/SwXMLSectionList.cxx
@@ -32,9 +32,9 @@ sal_Char const sXML_np__text[] = "_otext";
// #110680#
SwXMLSectionList::SwXMLSectionList(
- const uno::Reference< uno::XComponentContext > xContext,
+ const uno::Reference< uno::XComponentContext >& rContext,
std::vector<OUString*> &rNewSectionList)
-: SvXMLImport( xContext, "" ),
+: SvXMLImport( rContext, "" ),
rSectionList ( rNewSectionList )
{
GetNamespaceMap().Add( OUString( sXML_np__office ),
diff --git a/sw/source/core/unocore/unodraw.cxx b/sw/source/core/unocore/unodraw.cxx
index 87a888f20407..cc83db110ed4 100644
--- a/sw/source/core/unocore/unodraw.cxx
+++ b/sw/source/core/unocore/unodraw.cxx
@@ -257,9 +257,9 @@ const SdrMarkList& SwFmDrawPage::PreGroup(const uno::Reference< drawing::XShape
return rMarkList;
}
-void SwFmDrawPage::PreUnGroup(const uno::Reference< drawing::XShapeGroup > xShapeGroup)
+void SwFmDrawPage::PreUnGroup(const uno::Reference< drawing::XShapeGroup >& rShapeGroup)
{
- uno::Reference< drawing::XShape > xShape( xShapeGroup, uno::UNO_QUERY);
+ uno::Reference< drawing::XShape > xShape( rShapeGroup, uno::UNO_QUERY);
_SelectObjectInView( xShape, GetPageView() );
}
@@ -818,7 +818,7 @@ uno::Reference< drawing::XShapeGroup > SwXDrawPage::group(const uno::Reference<
return xRet;
}
-void SwXDrawPage::ungroup(const uno::Reference< drawing::XShapeGroup > & xShapeGroup) throw( uno::RuntimeException, std::exception )
+void SwXDrawPage::ungroup(const uno::Reference< drawing::XShapeGroup > & rShapeGroup) throw( uno::RuntimeException, std::exception )
{
SolarMutexGuard aGuard;
if(!pDoc)
@@ -828,7 +828,7 @@ void SwXDrawPage::ungroup(const uno::Reference< drawing::XShapeGroup > & xShapeG
SwFmDrawPage* pPage = GetSvxPage();
if(pPage) //TODO: can this be Null?
{
- pPage->PreUnGroup(xShapeGroup);
+ pPage->PreUnGroup(rShapeGroup);
UnoActionContext aContext(pDoc);
pDoc->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
@@ -2508,10 +2508,10 @@ awt::Point SwXShape::_GetAttrPosition()
the layout direction horizontal left-to-right.
#i31698#
*/
-awt::Point SwXShape::_ConvertPositionToHoriL2R( const awt::Point _aObjPos,
- const awt::Size _aObjSize )
+awt::Point SwXShape::_ConvertPositionToHoriL2R( const awt::Point& rObjPos,
+ const awt::Size& rObjSize )
{
- awt::Point aObjPosInHoriL2R( _aObjPos );
+ awt::Point aObjPosInHoriL2R( rObjPos );
SwFrmFmt* pFrmFmt = GetFrmFmt();
if ( pFrmFmt )
@@ -2526,13 +2526,13 @@ awt::Point SwXShape::_ConvertPositionToHoriL2R( const awt::Point _aObjPos,
break;
case SwFrmFmt::HORI_R2L:
{
- aObjPosInHoriL2R.X = -_aObjPos.X - _aObjSize.Width;
+ aObjPosInHoriL2R.X = -rObjPos.X - rObjSize.Width;
}
break;
case SwFrmFmt::VERT_R2L:
{
- aObjPosInHoriL2R.X = -_aObjPos.Y - _aObjSize.Width;
- aObjPosInHoriL2R.Y = _aObjPos.X;
+ aObjPosInHoriL2R.X = -rObjPos.Y - rObjSize.Width;
+ aObjPosInHoriL2R.Y = rObjPos.X;
}
break;
default:
@@ -2613,7 +2613,7 @@ drawing::HomogenMatrix3 SwXShape::_ConvertTransformationToLayoutDir(
/** method to adjust the positioning properties
#i31698#
*/
-void SwXShape::_AdjustPositionProperties( const awt::Point _aPosition )
+void SwXShape::_AdjustPositionProperties( const awt::Point& rPosition )
{
// handle x-position
// #i35007# - no handling of x-position, if drawing
@@ -2632,7 +2632,7 @@ void SwXShape::_AdjustPositionProperties( const awt::Point _aPosition )
sal_Int32 dCurrX = 0;
aHoriPos >>= dCurrX;
// change x-position attribute, if needed
- if ( dCurrX != _aPosition.X )
+ if ( dCurrX != rPosition.X )
{
// adjust x-position orientation to text::HoriOrientation::NONE, if needed
// Note: has to be done before setting x-position attribute
@@ -2649,7 +2649,7 @@ void SwXShape::_AdjustPositionProperties( const awt::Point _aPosition )
}
}
// set x-position attribute
- aHoriPos <<= _aPosition.X;
+ aHoriPos <<= rPosition.X;
setPropertyValue( aHoriPosPropStr, aHoriPos );
}
}
@@ -2662,7 +2662,7 @@ void SwXShape::_AdjustPositionProperties( const awt::Point _aPosition )
sal_Int32 dCurrY = 0;
aVertPos >>= dCurrY;
// change y-position attribute, if needed
- if ( dCurrY != _aPosition.Y )
+ if ( dCurrY != rPosition.Y )
{
// adjust y-position orientation to text::VertOrientation::NONE, if needed
// Note: has to be done before setting y-position attribute
@@ -2679,7 +2679,7 @@ void SwXShape::_AdjustPositionProperties( const awt::Point _aPosition )
}
}
// set y-position attribute
- aVertPos <<= _aPosition.Y;
+ aVertPos <<= rPosition.Y;
setPropertyValue( aVertPosPropStr, aVertPos );
}
}
diff --git a/sw/source/core/view/pagepreviewlayout.cxx b/sw/source/core/view/pagepreviewlayout.cxx
index 26ea7c01c5f3..d4a7b466ac6d 100644
--- a/sw/source/core/view/pagepreviewlayout.cxx
+++ b/sw/source/core/view/pagepreviewlayout.cxx
@@ -291,7 +291,7 @@ bool SwPagePreviewLayout::ReInit()
@note _nProposedStartPageNum, _onStartPageNum are absolute
*/
bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
- const Point _aProposedStartPos,
+ const Point& rProposedStartPos,
const Size& _rPxWinSize,
sal_uInt16& _onStartPageNum,
Rectangle& _orDocPreviewPaintRect,
@@ -314,9 +314,9 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
return false;
bool bStartPosRangeValid =
- _aProposedStartPos.X() >= 0 && _aProposedStartPos.Y() >= 0 &&
- _aProposedStartPos.X() <= maPreviewDocRect.Right() &&
- _aProposedStartPos.Y() <= maPreviewDocRect.Bottom();
+ rProposedStartPos.X() >= 0 && rProposedStartPos.Y() >= 0 &&
+ rProposedStartPos.X() <= maPreviewDocRect.Right() &&
+ rProposedStartPos.Y() <= maPreviewDocRect.Bottom();
OSL_ENSURE( bStartPosRangeValid,
"proposed start position out of range - no prepare of preview paint");
if ( !bStartPosRangeValid )
@@ -328,7 +328,7 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
return false;
bool bStartInfoValid = _nProposedStartPageNum > 0 ||
- _aProposedStartPos != Point(0,0);
+ rProposedStartPos != Point(0,0);
if ( !bStartInfoValid )
nProposedStartPageNum = 1;
}
@@ -383,9 +383,9 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
// determine column and row of proposed start position.
// Note: paint starts at point (0,0)
const sal_uInt16 nColOfProposed =
- static_cast<sal_uInt16>(_aProposedStartPos.X() / mnColWidth) + 1;
+ static_cast<sal_uInt16>(rProposedStartPos.X() / mnColWidth) + 1;
const sal_uInt16 nRowOfProposed =
- static_cast<sal_uInt16>(_aProposedStartPos.Y() / mnRowHeight) + 1;
+ static_cast<sal_uInt16>(rProposedStartPos.Y() / mnRowHeight) + 1;
// determine start page == page at proposed start position
// OD 19.02.2003 #107369# - leaving left-top-corner blank is
// controlled by <mbBookPreview>.
@@ -413,11 +413,11 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
mnPaintStartRow = nRowOfProposed;
// page offset
maPaintStartPageOffset.X() =
- (_aProposedStartPos.X() % mnColWidth) - mnXFree;
+ (rProposedStartPos.X() % mnColWidth) - mnXFree;
maPaintStartPageOffset.Y() =
- (_aProposedStartPos.Y() % mnRowHeight) - mnYFree;
+ (rProposedStartPos.Y() % mnRowHeight) - mnYFree;
// virtual preview document offset.
- maPaintPreviewDocOffset = _aProposedStartPos;
+ maPaintPreviewDocOffset = rProposedStartPos;
}
// determine additional paint offset, if preview layout fits into window.
@@ -897,7 +897,7 @@ bool SwPagePreviewLayout::CalcStartValuesForSelectedPageMove(
struct PreviewPosInsidePagePred
{
const Point mnPreviewPos;
- PreviewPosInsidePagePred( const Point _nPreviewPos ) : mnPreviewPos( _nPreviewPos ) {};
+ PreviewPosInsidePagePred( const Point& rPreviewPos ) : mnPreviewPos( rPreviewPos ) {};
bool operator() ( const PreviewPage* _pPreviewPage )
{
if ( _pPreviewPage->bVisible )
@@ -909,7 +909,7 @@ struct PreviewPosInsidePagePred
}
};
-bool SwPagePreviewLayout::IsPreviewPosInDocPreviewPage( const Point _aPreviewPos,
+bool SwPagePreviewLayout::IsPreviewPosInDocPreviewPage( const Point& rPreviewPos,
Point& _orDocPos,
bool& _obPosInEmptyPage,
sal_uInt16& _onPageNum ) const
@@ -922,7 +922,7 @@ bool SwPagePreviewLayout::IsPreviewPosInDocPreviewPage( const Point _aPreviewPo
std::vector<PreviewPage*>::const_iterator aFoundPreviewPageIter =
std::find_if( maPreviewPages.begin(), maPreviewPages.end(),
- PreviewPosInsidePagePred( _aPreviewPos ) );
+ PreviewPosInsidePagePred( rPreviewPos ) );
if ( aFoundPreviewPageIter != maPreviewPages.end() )
{
@@ -932,7 +932,7 @@ bool SwPagePreviewLayout::IsPreviewPosInDocPreviewPage( const Point _aPreviewPo
if ( !_obPosInEmptyPage )
{
// given preview position inside a normal page
- _orDocPos = _aPreviewPos -
+ _orDocPos = rPreviewPos -
(*aFoundPreviewPageIter)->aPreviewWinPos +
(*aFoundPreviewPageIter)->aLogicPos;
return true;
@@ -986,7 +986,7 @@ SwTwips SwPagePreviewLayout::GetWinPagesScrollAmount(
OD 12.12.2002 #103492#
*/
-bool SwPagePreviewLayout::Paint( const Rectangle _aOutRect ) const
+bool SwPagePreviewLayout::Paint(const Rectangle& rOutRect) const
{
// check environment and parameters
{
@@ -1027,7 +1027,7 @@ bool SwPagePreviewLayout::Paint( const Rectangle _aOutRect ) const
// paint preview background
{
- SwRegionRects aPreviewBackgrdRegion( _aOutRect );
+ SwRegionRects aPreviewBackgrdRegion(rOutRect);
// calculate preview background rectangles
for ( std::vector<PreviewPage*>::const_iterator aPageIter = maPreviewPages.begin();
aPageIter != maPreviewPages.end();
@@ -1044,7 +1044,7 @@ bool SwPagePreviewLayout::Paint( const Rectangle _aOutRect ) const
}
// prepare data for paint of pages
- const Rectangle aPxOutRect( pOutputDev->LogicToPixel( _aOutRect ) );
+ const Rectangle aPxOutRect( pOutputDev->LogicToPixel(rOutRect) );
MapMode aMapMode( pOutputDev->GetMapMode() );
MapMode aSavedMapMode = aMapMode;
@@ -1150,7 +1150,7 @@ bool SwPagePreviewLayout::Paint( const Rectangle _aOutRect ) const
OD 18.12.2002 #103492#
*/
-void SwPagePreviewLayout::Repaint( const Rectangle _aInvalidCoreRect ) const
+void SwPagePreviewLayout::Repaint( const Rectangle& rInvalidCoreRect ) const
{
// check environment and parameters
{
@@ -1183,9 +1183,9 @@ void SwPagePreviewLayout::Repaint( const Rectangle _aInvalidCoreRect ) const
continue;
Rectangle aPageRect( (*aPageIter)->aLogicPos, (*aPageIter)->aPageSize );
- if ( _aInvalidCoreRect.IsOver( aPageRect ) )
+ if ( rInvalidCoreRect.IsOver( aPageRect ) )
{
- aPageRect.Intersection( _aInvalidCoreRect );
+ aPageRect.Intersection(rInvalidCoreRect);
Rectangle aInvalidPreviewRect = aPageRect;
aInvalidPreviewRect.SetPos( aInvalidPreviewRect.TopLeft() -
(*aPageIter)->aLogicPos +
diff --git a/sw/source/filter/html/htmlforw.cxx b/sw/source/filter/html/htmlforw.cxx
index a73b92ea8df2..3cff8a21a022 100644
--- a/sw/source/filter/html/htmlforw.cxx
+++ b/sw/source/filter/html/htmlforw.cxx
@@ -81,7 +81,7 @@ const sal_uInt32 HTML_FRMOPTS_IMG_CONTROL_CSS1 =
HTML_FRMOPT_S_SPACE;
static void lcl_html_outEvents( SvStream& rStrm,
- const uno::Reference< form::XFormComponent > rFormComp,
+ const uno::Reference< form::XFormComponent >& rFormComp,
bool bCfgStarBasic,
rtl_TextEncoding eDestEnc,
OUString *pNonConvertableChars )
diff --git a/sw/source/filter/html/htmltab.cxx b/sw/source/filter/html/htmltab.cxx
index a07185a6bd9c..56a63344b5b8 100644
--- a/sw/source/filter/html/htmltab.cxx
+++ b/sw/source/filter/html/htmltab.cxx
@@ -228,7 +228,7 @@ public:
// Fill a not empty cell
void Set( HTMLTableCnts *pCnts, sal_uInt16 nRSpan, sal_uInt16 nCSpan,
sal_Int16 eVertOri, SvxBrushItem *pBGBrush,
- ::boost::shared_ptr<SvxBoxItem> const pBoxItem,
+ ::boost::shared_ptr<SvxBoxItem> const& rBoxItem,
bool bHasNumFmt, sal_uInt32 nNumFmt,
bool bHasValue, double nValue, bool bNoWrap, bool bCovered );
@@ -548,7 +548,7 @@ public:
void InsertCell( HTMLTableCnts *pCnts, sal_uInt16 nRowSpan, sal_uInt16 nColSpan,
sal_uInt16 nWidth, bool bRelWidth, sal_uInt16 nHeight,
sal_Int16 eVertOri, SvxBrushItem *pBGBrush,
- boost::shared_ptr<SvxBoxItem> const pBoxItem,
+ boost::shared_ptr<SvxBoxItem> const& rBoxItem,
bool bHasNumFmt, sal_uInt32 nNumFmt,
bool bHasValue, double nValue, bool bNoWrap );
@@ -704,7 +704,7 @@ HTMLTableCell::~HTMLTableCell()
void HTMLTableCell::Set( HTMLTableCnts *pCnts, sal_uInt16 nRSpan, sal_uInt16 nCSpan,
sal_Int16 eVert, SvxBrushItem *pBrush,
- ::boost::shared_ptr<SvxBoxItem> const pBoxItem,
+ ::boost::shared_ptr<SvxBoxItem> const& rBoxItem,
bool bHasNF, sal_uInt32 nNF, bool bHasV, double nVal,
bool bNWrap, bool bCovered )
{
@@ -714,7 +714,7 @@ void HTMLTableCell::Set( HTMLTableCnts *pCnts, sal_uInt16 nRSpan, sal_uInt16 nCS
bProtected = false;
eVertOri = eVert;
pBGBrush = pBrush;
- m_pBoxItem = pBoxItem;
+ m_pBoxItem = rBoxItem;
bHasNumFmt = bHasNF;
bHasValue = bHasV;
@@ -2060,7 +2060,7 @@ void HTMLTable::InsertCell( HTMLTableCnts *pCnts,
sal_uInt16 nRowSpan, sal_uInt16 nColSpan,
sal_uInt16 nCellWidth, bool bRelWidth, sal_uInt16 nCellHeight,
sal_Int16 eVertOrient, SvxBrushItem *pBGBrushItem,
- boost::shared_ptr<SvxBoxItem> const pBoxItem,
+ boost::shared_ptr<SvxBoxItem> const& rBoxItem,
bool bHasNumFmt, sal_uInt32 nNumFmt,
bool bHasValue, double nValue, bool bNoWrap )
{
@@ -2139,7 +2139,7 @@ void HTMLTable::InsertCell( HTMLTableCnts *pCnts,
{
const bool bCovered = i != nColSpan || j != nRowSpan;
GetCell( nRowsReq-j, nColsReq-i )
- ->Set( pCnts, j, i, eVertOrient, pBGBrushItem, pBoxItem,
+ ->Set( pCnts, j, i, eVertOrient, pBGBrushItem, rBoxItem,
bHasNumFmt, nNumFmt, bHasValue, nValue, bNoWrap, bCovered );
}
}
diff --git a/sw/source/filter/xml/xmlexp.cxx b/sw/source/filter/xml/xmlexp.cxx
index ba6c78e7f033..14630ec4a3e9 100644
--- a/sw/source/filter/xml/xmlexp.cxx
+++ b/sw/source/filter/xml/xmlexp.cxx
@@ -83,9 +83,9 @@ using namespace ::com::sun::star::xforms;
using namespace ::xmloff::token;
SwXMLExport::SwXMLExport(
- const uno::Reference< uno::XComponentContext > xContext,
+ const uno::Reference< uno::XComponentContext >& rContext,
OUString const & implementationName, SvXMLExportFlags nExportFlags)
-: SvXMLExport( util::MeasureUnit::INCH, xContext, implementationName, XML_TEXT,
+: SvXMLExport( util::MeasureUnit::INCH, rContext, implementationName, XML_TEXT,
nExportFlags ),
pTableItemMapper( 0 ),
pTableLines( 0 ),
diff --git a/sw/source/filter/xml/xmlexp.hxx b/sw/source/filter/xml/xmlexp.hxx
index 08f86a4e3172..a16aeca00f32 100644
--- a/sw/source/filter/xml/xmlexp.hxx
+++ b/sw/source/filter/xml/xmlexp.hxx
@@ -116,7 +116,7 @@ protected:
public:
SwXMLExport(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > xContext,
+ const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rContext,
OUString const & implementationName, SvXMLExportFlags nExportFlags);
virtual ~SwXMLExport();
diff --git a/sw/source/filter/xml/xmlimp.cxx b/sw/source/filter/xml/xmlimp.cxx
index ab8c9cc68f4b..f66c67f27559 100644
--- a/sw/source/filter/xml/xmlimp.cxx
+++ b/sw/source/filter/xml/xmlimp.cxx
@@ -403,9 +403,9 @@ SvXMLImportContext *SwXMLImport::CreateContext(
}
SwXMLImport::SwXMLImport(
- const uno::Reference< uno::XComponentContext > xContext,
+ const uno::Reference< uno::XComponentContext >& rContext,
OUString const & implementationName, SvXMLImportFlags nImportFlags)
-: SvXMLImport( xContext, implementationName, nImportFlags ),
+: SvXMLImport( rContext, implementationName, nImportFlags ),
pSttNdIdx( 0 ),
pTableItemMapper( 0 ),
pDocElemTokenMap( 0 ),
diff --git a/sw/source/filter/xml/xmlimp.hxx b/sw/source/filter/xml/xmlimp.hxx
index 2e04a0a4a9e2..47b12f8a8208 100644
--- a/sw/source/filter/xml/xmlimp.hxx
+++ b/sw/source/filter/xml/xmlimp.hxx
@@ -108,7 +108,7 @@ protected:
public:
SwXMLImport(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > xContext,
+ const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rContext,
OUString const & implementationName, SvXMLImportFlags nImportFlags);
virtual ~SwXMLImport() throw();
diff --git a/writerfilter/source/dmapper/DomainMapper.cxx b/writerfilter/source/dmapper/DomainMapper.cxx
index 4e2bf14d0fbb..de167850a28f 100644
--- a/writerfilter/source/dmapper/DomainMapper.cxx
+++ b/writerfilter/source/dmapper/DomainMapper.cxx
@@ -1089,7 +1089,7 @@ sal_Int32 lcl_getCurrentNumberingProperty(
}
// In rtl-paragraphs the meaning of left/right are to be exchanged
-static bool ExchangeLeftRight( const PropertyMapPtr rContext, DomainMapper_Impl* m_pImpl )
+static bool ExchangeLeftRight(const PropertyMapPtr& rContext, DomainMapper_Impl* m_pImpl)
{
bool bExchangeLeftRight = false;
boost::optional<PropertyMap::Property> aPropPara = rContext->getProperty(PROP_WRITING_MODE);
@@ -1118,9 +1118,9 @@ static bool ExchangeLeftRight( const PropertyMapPtr rContext, DomainMapper_Impl*
}
/// Check if the style or its parent has a list id, recursively.
-static sal_Int32 lcl_getListId(const StyleSheetEntryPtr pEntry, const StyleSheetTablePtr pStyleTable)
+static sal_Int32 lcl_getListId(const StyleSheetEntryPtr& rEntry, const StyleSheetTablePtr& rStyleTable)
{
- const StyleSheetPropertyMap* pEntryProperties = dynamic_cast<const StyleSheetPropertyMap*>(pEntry->pProperties.get());
+ const StyleSheetPropertyMap* pEntryProperties = dynamic_cast<const StyleSheetPropertyMap*>(rEntry->pProperties.get());
if (!pEntryProperties)
return -1;
@@ -1130,15 +1130,15 @@ static sal_Int32 lcl_getListId(const StyleSheetEntryPtr pEntry, const StyleSheet
return nListId;
// The style has no parent.
- if (pEntry->sBaseStyleIdentifier.isEmpty())
+ if (rEntry->sBaseStyleIdentifier.isEmpty())
return -1;
- const StyleSheetEntryPtr pParent = pStyleTable->FindStyleSheetByISTD(pEntry->sBaseStyleIdentifier);
+ const StyleSheetEntryPtr pParent = rStyleTable->FindStyleSheetByISTD(rEntry->sBaseStyleIdentifier);
// No such parent style or loop in the style hierarchy.
- if (!pParent || pParent == pEntry)
+ if (!pParent || pParent == rEntry)
return -1;
- return lcl_getListId(pParent, pStyleTable);
+ return lcl_getListId(pParent, rStyleTable);
}
void DomainMapper::sprmWithProps( Sprm& rSprm, PropertyMapPtr rContext )
@@ -3171,7 +3171,7 @@ void DomainMapper::lcl_info(const std::string & /*info_*/)
{
}
-void DomainMapper::handleUnderlineType(const Id nId, const ::std::shared_ptr<PropertyMap> pContext)
+void DomainMapper::handleUnderlineType(const Id nId, const ::std::shared_ptr<PropertyMap>& rContext)
{
sal_Int16 nUnderline = awt::FontUnderline::NONE;
@@ -3181,7 +3181,7 @@ void DomainMapper::handleUnderlineType(const Id nId, const ::std::shared_ptr<Pro
nUnderline = awt::FontUnderline::NONE;
break;
case NS_ooxml::LN_Value_ST_Underline_words:
- pContext->Insert(PROP_CHAR_WORD_MODE, uno::makeAny(true));
+ rContext->Insert(PROP_CHAR_WORD_MODE, uno::makeAny(true));
// fall-through intended
case NS_ooxml::LN_Value_ST_Underline_single:
nUnderline = awt::FontUnderline::SINGLE;
@@ -3232,10 +3232,10 @@ void DomainMapper::handleUnderlineType(const Id nId, const ::std::shared_ptr<Pro
nUnderline = awt::FontUnderline::DOUBLEWAVE;
break;
}
- pContext->Insert(PROP_CHAR_UNDERLINE, uno::makeAny(nUnderline));
+ rContext->Insert(PROP_CHAR_UNDERLINE, uno::makeAny(nUnderline));
}
-void DomainMapper::handleParaJustification(const sal_Int32 nIntValue, const ::std::shared_ptr<PropertyMap> pContext, const bool bExchangeLeftRight)
+void DomainMapper::handleParaJustification(const sal_Int32 nIntValue, const ::std::shared_ptr<PropertyMap>& rContext, const bool bExchangeLeftRight)
{
sal_Int16 nAdjust = 0;
sal_Int16 nLastLineAdjust = 0;
@@ -3264,8 +3264,8 @@ void DomainMapper::handleParaJustification(const sal_Int32 nIntValue, const ::st
nAdjust = static_cast< sal_Int16 > (bExchangeLeftRight ? style::ParagraphAdjust_RIGHT : style::ParagraphAdjust_LEFT);
break;
}
- pContext->Insert( PROP_PARA_ADJUST, uno::makeAny( nAdjust ) );
- pContext->Insert( PROP_PARA_LAST_LINE_ADJUST, uno::makeAny( nLastLineAdjust ) );
+ rContext->Insert( PROP_PARA_ADJUST, uno::makeAny( nAdjust ) );
+ rContext->Insert( PROP_PARA_LAST_LINE_ADJUST, uno::makeAny( nLastLineAdjust ) );
m_pImpl->appendGrabBag(m_pImpl->m_aInteropGrabBag, "jc", aStringValue);
}
diff --git a/writerfilter/source/dmapper/DomainMapper.hxx b/writerfilter/source/dmapper/DomainMapper.hxx
index 2c2065862e87..988c7ab8396d 100644
--- a/writerfilter/source/dmapper/DomainMapper.hxx
+++ b/writerfilter/source/dmapper/DomainMapper.hxx
@@ -163,8 +163,8 @@ private:
// Table
virtual void lcl_entry(int pos, writerfilter::Reference<Properties>::Pointer_t ref) SAL_OVERRIDE;
- void handleUnderlineType(const Id nId, const ::std::shared_ptr<PropertyMap> pContext);
- void handleParaJustification(const sal_Int32 nIntValue, const ::std::shared_ptr<PropertyMap> pContext, const bool bExchangeLeftRight);
+ void handleUnderlineType(const Id nId, const ::std::shared_ptr<PropertyMap>& rContext);
+ void handleParaJustification(const sal_Int32 nIntValue, const ::std::shared_ptr<PropertyMap>& rContext, const bool bExchangeLeftRight);
bool getColorFromId(const Id, sal_Int32 &nColor);
sal_Int16 getEmphasisValue(const sal_Int32 nIntValue);
OUString getBracketStringFromEnum(const sal_Int32 nIntValue, const bool bIsPrefix = true);
diff --git a/writerfilter/source/dmapper/DomainMapperTableHandler.cxx b/writerfilter/source/dmapper/DomainMapperTableHandler.cxx
index de9467eea2d2..b31d16d20e50 100644
--- a/writerfilter/source/dmapper/DomainMapperTableHandler.cxx
+++ b/writerfilter/source/dmapper/DomainMapperTableHandler.cxx
@@ -84,18 +84,18 @@ void DomainMapperTableHandler::startTable(unsigned int nRows,
-PropertyMapPtr lcl_SearchParentStyleSheetAndMergeProperties(const StyleSheetEntryPtr pStyleSheet, StyleSheetTablePtr pStyleSheetTable)
+PropertyMapPtr lcl_SearchParentStyleSheetAndMergeProperties(const StyleSheetEntryPtr& rStyleSheet, StyleSheetTablePtr pStyleSheetTable)
{
PropertyMapPtr pRet;
- if (!pStyleSheet)
+ if (!rStyleSheet)
return pRet;
- if(!pStyleSheet->sBaseStyleIdentifier.isEmpty())
+ if(!rStyleSheet->sBaseStyleIdentifier.isEmpty())
{
- const StyleSheetEntryPtr pParentStyleSheet = pStyleSheetTable->FindStyleSheetByISTD( pStyleSheet->sBaseStyleIdentifier );
+ const StyleSheetEntryPtr pParentStyleSheet = pStyleSheetTable->FindStyleSheetByISTD(rStyleSheet->sBaseStyleIdentifier);
//a loop in the style hierarchy, bail out
- if (pParentStyleSheet == pStyleSheet)
+ if (pParentStyleSheet == rStyleSheet)
return pRet;
pRet = lcl_SearchParentStyleSheetAndMergeProperties( pParentStyleSheet, pStyleSheetTable );
@@ -107,7 +107,7 @@ PropertyMapPtr lcl_SearchParentStyleSheetAndMergeProperties(const StyleSheetEntr
if (pRet)
{
- pRet->InsertProps(pStyleSheet->pProperties);
+ pRet->InsertProps(rStyleSheet->pProperties);
}
return pRet;
diff --git a/writerfilter/source/dmapper/PropertyMap.cxx b/writerfilter/source/dmapper/PropertyMap.cxx
index 63995b88a901..9cd85d41b035 100644
--- a/writerfilter/source/dmapper/PropertyMap.cxx
+++ b/writerfilter/source/dmapper/PropertyMap.cxx
@@ -352,22 +352,20 @@ void PropertyMap::dumpXml( const TagLogger::Pointer_t pLogger ) const
}
#endif
-void PropertyMap::InsertProps(const PropertyMapPtr pMap)
+void PropertyMap::InsertProps(const PropertyMapPtr& rMap)
{
- if(pMap)
+ if (rMap)
{
- MapIterator pEnd = pMap->m_vMap.end();
- for ( MapIterator iter = pMap->m_vMap.begin(); iter!=pEnd; ++iter )
+ MapIterator pEnd = rMap->m_vMap.end();
+ for ( MapIterator iter = rMap->m_vMap.begin(); iter!=pEnd; ++iter )
m_vMap[iter->first] = iter->second;
- insertTableProperties(pMap.get());
+ insertTableProperties(rMap.get());
Invalidate();
}
}
-
-
void PropertyMap::insertTableProperties( const PropertyMap* )
{
#ifdef DEBUG_WRITERFILTER
diff --git a/writerfilter/source/dmapper/PropertyMap.hxx b/writerfilter/source/dmapper/PropertyMap.hxx
index a1bb5c63dd5e..e430af59195b 100644
--- a/writerfilter/source/dmapper/PropertyMap.hxx
+++ b/writerfilter/source/dmapper/PropertyMap.hxx
@@ -145,7 +145,7 @@ public:
void Erase( PropertyIds eId);
//Imports properties from pMap, overwriting those with the same PropertyIds as the current map
- void InsertProps(const std::shared_ptr<PropertyMap> pMap);
+ void InsertProps(const std::shared_ptr<PropertyMap>& rMap);
//Returns a copy of the property if it exists, .first is its PropertyIds and .second is its Value (type css::uno::Any)
boost::optional<Property> getProperty( PropertyIds eId ) const;
diff --git a/writerfilter/source/dmapper/PropertyMapHelper.cxx b/writerfilter/source/dmapper/PropertyMapHelper.cxx
index ad503a6795e1..a735a1d3267a 100644
--- a/writerfilter/source/dmapper/PropertyMapHelper.cxx
+++ b/writerfilter/source/dmapper/PropertyMapHelper.cxx
@@ -28,7 +28,7 @@ namespace dmapper
using namespace ::com::sun::star;
-void lcl_DumpTableColumnSeparators(const TagLogger::Pointer_t pLogger, const uno::Any & rTableColumnSeparators)
+void lcl_DumpTableColumnSeparators(const TagLogger::Pointer_t& pLogger, const uno::Any & rTableColumnSeparators)
{
(void) pLogger;
(void) rTableColumnSeparators;
diff --git a/writerfilter/source/dmapper/PropertyMapHelper.hxx b/writerfilter/source/dmapper/PropertyMapHelper.hxx
index 43620eb07458..819fc8b6ce7c 100644
--- a/writerfilter/source/dmapper/PropertyMapHelper.hxx
+++ b/writerfilter/source/dmapper/PropertyMapHelper.hxx
@@ -28,7 +28,7 @@ namespace writerfilter
namespace dmapper
{
-void lcl_DumpTableColumnSeparators(const TagLogger::Pointer_t pLogger,
+void lcl_DumpTableColumnSeparators(const TagLogger::Pointer_t& rLogger,
const css::uno::Any & rTableColumnSeparators);
#ifdef DEBUG_WRITERFILTER
void lcl_DumpPropertyValues(const TagLogger::Pointer_t pLogger,
diff --git a/writerfilter/source/ooxml/OOXMLPropertySetImpl.cxx b/writerfilter/source/ooxml/OOXMLPropertySetImpl.cxx
index fcd7e2bd8d6e..64a728550d5b 100644
--- a/writerfilter/source/ooxml/OOXMLPropertySetImpl.cxx
+++ b/writerfilter/source/ooxml/OOXMLPropertySetImpl.cxx
@@ -391,8 +391,8 @@ OOXMLValue * OOXMLInputStreamValue::clone() const
struct OOXMLPropertySetImplCompare
*/
-bool OOXMLPropertySetImplCompare::operator()(const OOXMLProperty::Pointer_t x,
- const OOXMLProperty::Pointer_t y) const
+bool OOXMLPropertySetImplCompare::operator()(const OOXMLProperty::Pointer_t& x,
+ const OOXMLProperty::Pointer_t& y) const
{
bool bResult = false;
diff --git a/writerfilter/source/ooxml/OOXMLPropertySetImpl.hxx b/writerfilter/source/ooxml/OOXMLPropertySetImpl.hxx
index 79308ab41fd7..26c1715c393c 100644
--- a/writerfilter/source/ooxml/OOXMLPropertySetImpl.hxx
+++ b/writerfilter/source/ooxml/OOXMLPropertySetImpl.hxx
@@ -153,8 +153,8 @@ public:
struct OOXMLPropertySetImplCompare
{
- bool operator()(const OOXMLProperty::Pointer_t x,
- const OOXMLProperty::Pointer_t y) const;
+ bool operator()(const OOXMLProperty::Pointer_t& x,
+ const OOXMLProperty::Pointer_t& y) const;
};
class OOXMLPropertySetImpl : public OOXMLPropertySet
diff --git a/sw/source/core/layout/paintfrm.cxx b/sw/source/core/layout/paintfrm.cxx
index 2589732988b4..d3d9ba46345e 100644
--- a/sw/source/core/layout/paintfrm.cxx
+++ b/sw/source/core/layout/paintfrm.cxx
@@ -470,8 +470,8 @@ SwSavePaintStatics::~SwSavePaintStatics()
* 0 if A and B can't be merged
**/
static sal_uInt8 lcl_TryMergeLines(
- pair<double, double> const mergeA,
- pair<double, double> const mergeB,
+ pair<double, double> const& mergeA,
+ pair<double, double> const& mergeB,
SwPaintProperties& properties)
{
double const fMergeGap(properties.nSPixelSzW + properties.nSHalfPixelSzW); // NOT static!
@@ -6338,7 +6338,7 @@ static void lcl_paintBitmapExToRect(OutputDevice *pOut, const Point& aPoint, con
}
}
/*static*/ void SwPageFrm::PaintNotesSidebarArrows(const Point &aMiddleFirst, const Point &aMiddleSecond, SwViewShell* _pViewShell, const Color aColorUp, const Color aColorDown)
{
Polygon aTriangleUp(3);
Polygon aTriangleDown(3);
@@ -6351,9 +6351,9 @@ static void lcl_paintBitmapExToRect(OutputDevice *pOut, const Point& aPoint, con
aTriangleDown.SetPoint(aMiddleSecond + Point(_pViewShell->GetOut()->PixelToLogic(Size(+3,0)).Width(),_pViewShell->GetOut()->PixelToLogic(Size(0,-3)).Height()),1);
aTriangleDown.SetPoint(aMiddleSecond + Point(0,_pViewShell->GetOut()->PixelToLogic(Size(0,3)).Height()),2);
- _pViewShell->GetOut()->SetFillColor(aColorUp);
+ _pViewShell->GetOut()->SetFillColor(rColorUp);
_pViewShell->GetOut()->DrawPolygon(aTriangleUp);
- _pViewShell->GetOut()->SetFillColor(aColorDown);
+ _pViewShell->GetOut()->SetFillColor(rColorDown);
_pViewShell->GetOut()->DrawPolygon(aTriangleDown);
}
@@ -6338,7 +6338,7 @@ static void lcl_paintBitmapExToRect(OutputDevice *pOut, const Point& aPoint, con
}
}
-/*static*/ void SwPageFrm::PaintNotesSidebarArrows(const Point &aMiddleFirst, const Point &aMiddleSecond, SwViewShell* _pViewShell, const Color aColorUp, const Color aColorDown)
+/*static*/ void SwPageFrm::PaintNotesSidebarArrows(const Point &aMiddleFirst, const Point &aMiddleSecond, SwViewShell* _pViewShell, const Color& rColorUp, const Color& rColorDown)
{
Polygon aTriangleUp(3);